@@ -1,3 +1,4 @@
+import decimal
 import logging
 
 import six
@@ -40,8 +41,14 @@ registry = ValidatorRegistry()
 
 @registry.register()
 def multipleOf(param, value, _):
-    quot, rem = divmod(value, param)
-    if rem != 0:
+    # This conversion to string is intentional because floats are imprecise.
+    # >>> decimal.Decimal(33.069)
+    # Decimal('33.0690000000000026147972675971686840057373046875')
+    # >>> decimal.Decimal('33.069')
+    # Decimal('33.069')
+    value = decimal.Decimal(str(value))
+    divisor = decimal.Decimal(str(param))
+    if value % divisor != 0:
         raise ValidationError("{0} is not a multiple of {1}".format(value, param))
 
 
