@@ -4,8 +4,8 @@ import logging
 import six
 
 from python_jsonschema_objects import util
-from python_jsonschema_objects.validators import registry, ValidationError
 from python_jsonschema_objects.util import lazy_format as fmt
+from python_jsonschema_objects.validators import ValidationError, registry
 
 logger = logging.getLogger(__name__)
 
@@ -118,7 +118,6 @@ class ArrayWrapper(collections.abc.MutableSequence):
         return True
 
     def validate_uniqueness(self):
-
         if getattr(self, "uniqueItems", False) is True:
             testset = set(repr(item) for item in self.data)
             if len(testset) != len(self.data):
@@ -129,7 +128,6 @@ class ArrayWrapper(collections.abc.MutableSequence):
                 )
 
     def validate_length(self):
-
         if getattr(self, "minItems", None) is not None:
             if len(self.data) < self.minItems:
                 raise ValidationError(
@@ -163,7 +161,8 @@ class ArrayWrapper(collections.abc.MutableSequence):
 
         type_checks = self.__itemtype__
         if not isinstance(type_checks, (tuple, list)):
-            # we were given items = {'type': 'blah'} ; thus ensure the type for all data.
+            # We were given items = {'type': 'blah'}.
+            # Thus ensure the type for all data.
             type_checks = [type_checks] * len(self.data)
         elif len(type_checks) > len(self.data):
             raise ValidationError(
@@ -214,6 +213,8 @@ class ArrayWrapper(collections.abc.MutableSequence):
                 try:
                     if isinstance(elem, (six.string_types, six.integer_types, float)):
                         val = typ(elem)
+                    elif isinstance(elem, classbuilder.LiteralValue):
+                        val = typ(elem._value)
                     else:
                         val = typ(**util.coerce_for_expansion(elem))
                 except TypeError as e:
@@ -302,7 +303,7 @@ class ArrayWrapper(collections.abc.MutableSequence):
                         addl_constraints=item_constraint,
                     )
                 elif isdict and "oneOf" in item_constraint:
-                    # We need to create a TypeProxy validator
+                    # We need to create a TypeProxy validator.
                     uri = "{0}_{1}".format(name, "<anonymous_list_type>")
                     type_array = klassbuilder.construct_objects(
                         item_constraint["oneOf"], uri
@@ -311,7 +312,8 @@ class ArrayWrapper(collections.abc.MutableSequence):
                     item_constraint = classbuilder.TypeProxy(type_array)
 
                 elif isdict and item_constraint.get("type") == "object":
-                    """ We need to create a ProtocolBase object for this anonymous definition"""
+                    # We need to create a ProtocolBase object for this
+                    # anonymous definition.
                     uri = "{0}_{1}".format(name, "<anonymous_list_type>")
                     item_constraint = klassbuilder.construct(uri, item_constraint)
 
